<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="14"/>
        <location filename="../src/ui_mainwindow.h" line="569"/>
        <source>Program_Name</source>
        <translation>Program_Namn</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="46"/>
        <location filename="../src/ui_mainwindow.h" line="571"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="49"/>
        <location filename="../src/ui_mainwindow.h" line="573"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="55"/>
        <location filename="../src/ui_mainwindow.h" line="575"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="87"/>
        <location filename="../src/ui_mainwindow.h" line="578"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="90"/>
        <location filename="../src/ui_mainwindow.h" line="580"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="96"/>
        <location filename="../src/ui_mainwindow.h" line="582"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="112"/>
        <location filename="../src/ui_mainwindow.h" line="584"/>
        <source>Back</source>
        <translation>Tillbaka</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="169"/>
        <location filename="../src/ui_mainwindow.h" line="586"/>
        <source>Next</source>
        <translation>Nästa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="194"/>
        <location filename="../src/ui_mainwindow.h" line="591"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="197"/>
        <location filename="../src/ui_mainwindow.h" line="593"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="203"/>
        <location filename="../src/ui_mainwindow.h" line="595"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="219"/>
        <location filename="../src/ui_mainwindow.h" line="597"/>
        <source>View Log</source>
        <translation>Se Logg</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="253"/>
        <location filename="../src/mainwindow.cpp" line="583"/>
        <location filename="../src/mainwindow.cpp" line="606"/>
        <location filename="../src/ui_mainwindow.h" line="598"/>
        <source>Select ISO</source>
        <translation>Välj ISO</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="263"/>
        <location filename="../src/ui_mainwindow.h" line="599"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Välj Mål USB-Enhet&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="273"/>
        <location filename="../src/ui_mainwindow.h" line="600"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Välj ISO-fil&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="289"/>
        <location filename="../src/ui_mainwindow.h" line="601"/>
        <source>Advanced Options</source>
        <translation>Avancerade Alternativ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="307"/>
        <location filename="../src/ui_mainwindow.h" line="602"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Skapa ext4 filsystem även om ett finns</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="314"/>
        <location filename="../src/ui_mainwindow.h" line="603"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Spara den ursprungliga boot-katalogen när en live-usb uppdateras</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="321"/>
        <location filename="../src/ui_mainwindow.h" line="605"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Använd gpt partionering i stället för msdos</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="324"/>
        <location filename="../src/ui_mainwindow.h" line="607"/>
        <source>GPT partitioning</source>
        <translation>GPT partionering</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="331"/>
        <location filename="../src/ui_mainwindow.h" line="608"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Uppdatera (uppdatera endast en existerande live-usb)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="338"/>
        <location filename="../src/ui_mainwindow.h" line="610"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Ersätt inte syslinux filer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="341"/>
        <location filename="../src/ui_mainwindow.h" line="612"/>
        <source>Keep syslinux files</source>
        <translation>Behåll syslinux filer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="348"/>
        <location filename="../src/ui_mainwindow.h" line="613"/>
        <source>Ignore USB/removable check</source>
        <translation>Gör inte USB/borttagbar kontroll</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="355"/>
        <location filename="../src/ui_mainwindow.h" line="614"/>
        <source>Temporarily disable automounting</source>
        <translation>Inaktivera automontering tillfälligt</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="365"/>
        <location filename="../src/ui_mainwindow.h" line="618"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Välj pmbr_boot disk flagga (bootar inte via UEFI)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="372"/>
        <location filename="../src/ui_mainwindow.h" line="619"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Använd inte fuseiso för att montera iso-filer</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="398"/>
        <location filename="../src/ui_mainwindow.h" line="620"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Storlek på ESP (uefi) partition:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="421"/>
        <location filename="../src/ui_mainwindow.h" line="621"/>
        <source>Verbosity (less to more):</source>
        <translation>Ordrikedom (mindre till mer)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="465"/>
        <location filename="../src/ui_mainwindow.h" line="623"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="506"/>
        <location filename="../src/ui_mainwindow.h" line="628"/>
        <source>Data partition format type</source>
        <translation>Datapartitionens formattyp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="460"/>
        <location filename="../src/ui_mainwindow.h" line="622"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="470"/>
        <location filename="../src/ui_mainwindow.h" line="624"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="475"/>
        <location filename="../src/ui_mainwindow.h" line="625"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="499"/>
        <location filename="../src/ui_mainwindow.h" line="627"/>
        <source>Make separate data partition (percent)</source>
        <translation>Gör en separat data-partition (procent)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="516"/>
        <location filename="../src/ui_mainwindow.h" line="629"/>
        <source>Refresh drive list</source>
        <translation>Förnya disk-listan</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="529"/>
        <location filename="../src/mainwindow.cpp" line="552"/>
        <location filename="../src/ui_mainwindow.h" line="630"/>
        <source>Show advanced options</source>
        <translation>Visa avancerade alternativ</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="548"/>
        <location filename="../src/ui_mainwindow.h" line="631"/>
        <source>Mode</source>
        <translation>Läge</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="563"/>
        <location filename="../src/ui_mainwindow.h" line="632"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation>Komplett läge - skrivbar Li&amp;veUSB</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="573"/>
        <location filename="../src/ui_mainwindow.h" line="634"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Read-only,  kan inte användas med persistens</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="576"/>
        <location filename="../src/ui_mainwindow.h" line="636"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation>bild &amp;läge - read-only LiveUSB (dd)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="589"/>
        <location filename="../src/ui_mainwindow.h" line="637"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>För andra distributioner än antiX/MX, använd avbildningsläge (dd).</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="637"/>
        <location filename="../src/ui_mainwindow.h" line="638"/>
        <source>Options</source>
        <translation>Valmöjligheter</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="675"/>
        <location filename="../src/ui_mainwindow.h" line="639"/>
        <source>Percent of USB-device to use:</source>
        <translation>Procent av USB-enhet som ska användas:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="682"/>
        <location filename="../src/ui_mainwindow.h" line="640"/>
        <source>Label ext partition:</source>
        <translation>Etikettera ext partition:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="730"/>
        <location filename="../src/ui_mainwindow.h" line="642"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Kör inte kommandon som påverkar usb-enheten</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="733"/>
        <location filename="../src/ui_mainwindow.h" line="644"/>
        <source>Dry run (no change to system)</source>
        <translation>Testkör (ingen förändring av systemet)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="740"/>
        <location filename="../src/ui_mainwindow.h" line="646"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>klona från en monterad  live-usb eller iso-fil</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="743"/>
        <location filename="../src/ui_mainwindow.h" line="648"/>
        <source>Clone a mounted live system</source>
        <translation>Klona ett monterat live system</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="750"/>
        <location filename="../src/ui_mainwindow.h" line="650"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Arrangera för att boota från en krypterad partition, kommer att fråga efter ett lösenord vid första start</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="753"/>
        <location filename="../src/ui_mainwindow.h" line="652"/>
        <source>Encrypt</source>
        <translation>Kryptera</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="760"/>
        <location filename="../src/ui_mainwindow.h" line="653"/>
        <source>Clone running live system</source>
        <translation>Klona det live-system som körs</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <location filename="../src/mainwindow.cpp" line="537"/>
        <location filename="../src/mainwindow.cpp" line="705"/>
        <source>Failure</source>
        <translation>Misslyckande</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="155"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Källa och mål är på samma enhet, var vänlig välj igen.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="750"/>
        <source>Source Error</source>
        <translation>Källfel</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="751"/>
        <source>Could not find the source linuxfs file.</source>
        <translation>Kunde inte hitta linuxfs källfil</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="772"/>
        <source>Warning: The target device (%1) is smaller than the source (%2). The data might not fit. Do you want to continue?</source>
        <translation>Varning: Målenheten (%1) är mindre än källan (%2). Datan kanske inte ryms. Vill du fortsätta?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="775"/>
        <source>Size Warning</source>
        <translation>Storleksvarning</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="783"/>
        <source>The target device %1 is larger than %2 GB.

This may indicate you have selected the wrong device.
Are you sure you want to proceed?</source>
        <translation>Målenheten %1 är större än %2 GB.

Detta kan indikera att du har valt fel enhet.
Är det säkert att du vill fortsätta?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="790"/>
        <source>Large Target Device Warning</source>
        <translation>Stor Målenhetsvarning</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="194"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the process is completed</source>
        <translation>Skriver %1 med &apos;dd&apos; kommando till /dev/%2,

Var vänlig vänta tills processen är klar</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="205"/>
        <source>MX Live Usb Maker</source>
        <translation>MX Live Usb Maker</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="395"/>
        <source>Success</source>
        <translation>Det lyckades</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="395"/>
        <source>LiveUSB creation successful!</source>
        <translation>Skapandet av LiveUSB gick bra</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="398"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Fel uppträdde i processen att skapa LiveUSB</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="464"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="464"/>
        <source>Please select a USB device to write to</source>
        <translation>Var vänlig välj en USB enhet att skriva till</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="467"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Dessa åtgärder kommer att förstöra alla data på 

</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="468"/>
        <source>Do you wish to continue?</source>
        <translation>Vill du fortsätta?</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="500"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="501"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="503"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program för att skapa en live-usb från en iso-fil, en annan live-usb, en live-cd/dvd, eller ett live-system som körs.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="506"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="507"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="514"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="522"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Välj en ISO-fil att skriva till USB-enheten</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="523"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation>ISO Files (*.iso);;All Files (*.*)</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="528"/>
        <location filename="../src/mainwindow.cpp" line="578"/>
        <source>Select Source Directory</source>
        <translation>Välj Käll Katalog</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="537"/>
        <source>Could not find linuxfs file</source>
        <translation>Kunde inte hitta linuxfs fil</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="552"/>
        <source>Hide advanced options</source>
        <translation>Dölj avancerade val</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="577"/>
        <location filename="../src/mainwindow.cpp" line="596"/>
        <source>Select Source</source>
        <translation>Välj Källa</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="582"/>
        <location filename="../src/mainwindow.cpp" line="604"/>
        <source>Select ISO file</source>
        <translation>Välj ISO-fil</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="598"/>
        <source>clone</source>
        <translation>klona</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="665"/>
        <source>Could not find a log file at: </source>
        <translation>Kunde inte hitta en loggfil  vid: </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/about.cpp" line="74"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="75"/>
        <location filename="../src/about.cpp" line="85"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="76"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../src/about.cpp" line="99"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="60"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program för att skapa en live-usb från en iso-fil, en annan live-usb, en live-cd/dvd, eller ett live-system som körs.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>filename</source>
        <translation>filnamn</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="64"/>
        <source>Name of .iso file to open</source>
        <translation>Namn på .iso fil att öppna</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="65"/>
        <source>[filename]</source>
        <translation>[filnamn]</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="93"/>
        <location filename="../src/main.cpp" line="102"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="94"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du verkar vara inloggad som root, var vänlig logga ut och logga in som vanlig användare för att använda detta program.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="102"/>
        <source>You must run this program as root.</source>
        <translation>Du måste köra detta program som administratör d.v.s med sudo.</translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="117"/>
        <source>version:</source>
        <translation>version:</translation>
    </message>
</context>
</TS>
